Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(628)

Unified Diff: chrome/browser/chrome_browser_main_android.cc

Issue 2200693002: Refactor CrashDump*Manager to use a shared CrashDumpObserver. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/chrome_browser_main_android.h ('k') | chrome/browser/chrome_content_browser_client.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chrome_browser_main_android.cc
diff --git a/chrome/browser/chrome_browser_main_android.cc b/chrome/browser/chrome_browser_main_android.cc
index dbb1287b135041a08702e99bcad0a6df5b2e89fe..b75607a699466cb2fdac364803bf104e08f52ef7 100644
--- a/chrome/browser/chrome_browser_main_android.cc
+++ b/chrome/browser/chrome_browser_main_android.cc
@@ -8,12 +8,14 @@
#include "base/command_line.h"
#include "base/files/file_path.h"
#include "base/files/file_util.h"
+#include "base/memory/ptr_util.h"
#include "base/path_service.h"
#include "base/trace_event/trace_event.h"
#include "chrome/browser/android/mojo/chrome_interface_registrar_android.h"
#include "chrome/browser/android/seccomp_support_detector.h"
#include "chrome/browser/signin/signin_manager_factory.h"
#include "chrome/common/chrome_paths.h"
+#include "chrome/common/descriptors_android.h"
#include "components/crash/content/app/breakpad_linux.h"
#include "components/crash/content/browser/crash_dump_manager_android.h"
#include "components/signin/core/browser/signin_manager.h"
@@ -46,10 +48,13 @@ ChromeBrowserMainPartsAndroid::~ChromeBrowserMainPartsAndroid() {
int ChromeBrowserMainPartsAndroid::PreCreateThreads() {
TRACE_EVENT0("startup", "ChromeBrowserMainPartsAndroid::PreCreateThreads")
- // The CrashDumpManager must be initialized before any child process is
- // created (as they need to access it during creation). Such processes
- // are created on the PROCESS_LAUNCHER thread, and so the manager is
- // initialized before that thread is created.
+// The CrashDumpManager must be registered before any child process is
+// created (as it needs to be notified during child process
+// creation). Such processes are created on the PROCESS_LAUNCHER
+// thread, and so the observer is initialized and the manager
+// registered before that thread is created.
+ crash_dump_observer_ = base::MakeUnique<breakpad::CrashDumpObserver>();
+
#if defined(GOOGLE_CHROME_BUILD)
// TODO(jcivelli): we should not initialize the crash-reporter when it was not
// enabled. Right now if it is disabled we still generate the minidumps but we
@@ -67,7 +72,8 @@ int ChromeBrowserMainPartsAndroid::PreCreateThreads() {
if (breakpad_enabled) {
base::FilePath crash_dump_dir;
PathService::Get(chrome::DIR_CRASH_DUMPS, &crash_dump_dir);
- crash_dump_manager_.reset(new breakpad::CrashDumpManager(crash_dump_dir));
+ crash_dump_observer_->RegisterClient(new breakpad::CrashDumpManager(
+ crash_dump_dir, kAndroidMinidumpDescriptor));
}
ui::SetLocalePaksStoredInApk(false);
« no previous file with comments | « chrome/browser/chrome_browser_main_android.h ('k') | chrome/browser/chrome_content_browser_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698